# edwh-pipcompile-plugin

[![PyPI - Version](https://img.shields.io/pypi/v/edwh-pipcompile-plugin.svg)](https://pypi.org/project/edwh-pipcompile-plugin)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/edwh-pipcompile-plugin.svg)](https://pypi.org/project/edwh-pipcompile-plugin)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)
- [Changelog](#changelog)

## Installation

```console
pip install edwh-pipcompile-plugin
```

But probably you want to install the whole edwh package:

```console
pipx install edwh[pip]
# or
pipx install edwh[plugins,omgeving]
```

## License

`edwh-pipcompile-plugin` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Changelog 

[See CHANGELOG.md](CHANGELOG.md)